#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::intruder - Intruder file detection module
#
package Security::intruder;

use Security::util::print;
use Security::util::read_config;
use Exporter;
use strict;
use warnings "all";

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( init check print );

our (%badfile);

sub init {
	print ( STDERR  "In Security::intruder::init()\n") if ( $main::opts{'d'} );

	# Read the config file for intruderfiles definitions.
	&read_config('intruderfiles');
}

sub check {
	print ( STDERR  "In Security::intruder::check()\n") if ( $main::opts{'d'} );

	foreach my $i ( @{$main::config{'intruderfiles'}} ) {
		$badfile{$i} = 1 if ( -f $i );
	}
}

sub print {
	print ( STDERR  "In Security::intruder::print()\n") if ( $main::opts{'d'} );

	&print_data ("\n\nchecking for known intruder files:\n", %badfile);
}

1;

__END__

=head1 NAME

Security::intruder - Intruder file detection.

=head1 SYNOPSIS

Security::intruder::init()

Security::intruder::check()

Security::intruder::print()

=head1 DESCRIPTION

Checks the list of files we should not see on the system.

=head1 API

This module implements the default API:

=over 4

=item C<init()>

Calls C<read_config (intruderfiles)> to get the list of files to
report on.

=item C<check()>

Looks through the list of files in C<intruderfiles> and records
any that were found.

=item C<print()>

Calls C<print_data ()> to print out the list of files that we found.

=back

=head1 CONFIGURATION OPTIONS

The script will call C<read_config> on the following config file options:

=over 4

=item C<intruderfiles>

The list of files to put into the report if we find them

=back

=head1 TODO

Rewrite this module to use output from chkrootkit, if it exists.

=cut

