#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::util::detaint - Common routine to detaint any external data
#
package Security::util::detaint;

use Exporter;
use Security::util::die;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT = qw( detaint $detaint_pattern );

our $detaint_pattern = qr|^([-+@\w.,/:\s\\%#\[\]\{\}\(\)]+)$|;

delete @ENV{qw(IFS CDPATH ENV BASH_ENV PATH)};

sub detaint {
	my ($var, @val) = @_;
	my (@v);

	no locale;
	#print "In detaint($var, ["  . join(',', @val) . "])\n" if ( $opts{'d'} );
	map {
		m|$detaint_pattern|;
		&security_die("Could not detaint $var ($_)\n") if ( defined $1 && $1 ne $_ );
		push @v, $1;
	} @val;

	return (@v);
}

1;

__END__

=head1 NAME

Security::util::detaint - Routine to read our config file

=head1 SYNOPSIS

use Security::util::detaint;

&detaint();

=head1 DESCRIPTION

The routine that reads the C<security.cf> file and sets up global
variables used by the program.

=head1 METHODS

The methods provided by this module

=over 4

=item C<detaint ()>

Reads the file as defined by C<$main::opts{'C'}> and sets the appropiate
config has entries in C<%main::config>.

=back

This module sets the following global variables

=over 4

=item <%main::cnfig>

=back

=head1 CONFIGURATION OPTIONS

The module is modified by the following configuration options

=over 4

=item $main::opts{'C'}

The file to read our config options from.

=back

=head1 SEE ALSO

L<perl>

=cut
