#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::util::read_config - Routine to read our config file
#
package Security::util::read_config;

use Data::Dumper;
use Security::util::die;
use Security::util::detaint;
use Exporter;
use strict;
use warnings;

$Data::Dumper::Terse = 1;

our @ISA = qw(Exporter);
our @EXPORT = qw( read_config );

sub read_config {
	my ($field) = @_;
	my $FP;

	print ( STDERR "In read_config($field)\n") if ( $main::opts{'d'} );

	# return if we do not have the config file set (most likely in 'make test' code)
	return if ( ! exists $main::opts{'C'} || ! defined $main::opts{'C'} );

	if (open ($FP, $main::opts{'C'})) {
		while (<$FP>) {
			chop;
			@{$main::config{$field}} = &detaint($field, split (/[ \t]+/o, substr ($_, index ($_, ' ')+1)))
				if (/^$field /);
		}
		close $FP;
	} else {
		# Use STDOUT for the errors since we can't connect (might be
		# reading mailhost)
		$main::opts{'M'} = '-';
		&security_die("Could not read config file ($main::opts{'C'})\n");
	}

	print STDERR $field . " => " . Dumper(\@{$main::config{$field}})
		if ( $main::opts{'d'} );
}

1;

__END__

=head1 NAME

Security::util::read_config - Routine to read our config file

=head1 SYNOPSIS

use Security::util::read_config;

&read_config();

=head1 DESCRIPTION

The routine that reads the C<security.cf> file and sets up global
variables used by the program.

=head1 METHODS

The methods provided by this module

=over 4

=item C<read_config ()>

Reads the file as defined by C<$main::opts{'C'}> and sets the appropiate
config has entries in C<%main::config>.

=back

This module sets the following global variables

=over 4

=item <%main::cnfig>

=back

=head1 CONFIGURATION OPTIONS

The module is modified by the following configuration options

=over 4

=item $main::opts{'C'}

The file to read our config options from.

=back

=head1 SEE ALSO

L<perl>

=cut
