#
#  Copyright 1996-2011 Jim Pirzyk / pirzyk.org
#  All rights reserved.
#
#  Security::util::stat - File stat(2) call module
#
package Security::util::stat;

use Exporter;
use Security::util::die;
use strict;
use warnings;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw( get_stat );

our (%stat, %lstat);

sub get_stat {
	my ($file, $type) = @_;

	if ( $type eq 'lstat' ) {
		@{$lstat{$file}} = lstat($file)
			if ( ! exists $lstat{$file} );
		return @{$lstat{$file}};
	} elsif ( $type eq 'stat' ) {
		@{$stat{$file}} = stat($file)
			if ( ! exists $stat{$file} );
		return @{$stat{$file}};
	} else {
		&security_die ("get_stat ($file, $type) not implemented (invalid type value)\n");
	}
}

1;

__END__

=head1 NAME

Security::util::stat - File stat(2) call module

=head1 SYNOPSIS

Security::util::get_stat($file, $type)

=head1 DESCRIPTION

Module to cache the stat call ouput for use in our program.

=head1 API

It provides the following API calls for other modules to use.

=over 4

=item C<get_stat($file, $type)>

A function to get the result of the L<stat(2)> or L<lstat(2)> of the 
given F<$file>.  Will cache the value so multiple calls to get_stat will
not result in multiple system calls.  C<$type> should be the literal
I<stat> or I<lstat>.

=back

=head1 SEE ALSO

L<lstat(2)>

L<stat(2)>

=cut
